[Libreoffice-commits] core.git: 3 commits - include/vcl vcl/source

Chris Sherlock chris.sherlock79 at gmail.com
Tue Apr 22 14:41:42 PDT 2014


 include/vcl/outdev.hxx                 |   42 ++++++++++++++++++---------------
 include/vcl/print.hxx                  |   18 +-------------
 include/vcl/virdev.hxx                 |    2 -
 include/vcl/window.hxx                 |    2 -
 vcl/source/gdi/bitmap.cxx              |    2 -
 vcl/source/gdi/embeddedfontshelper.cxx |    2 -
 vcl/source/gdi/pdfwriter_impl.cxx      |    6 ++--
 vcl/source/gdi/print.cxx               |   14 ++++++++---
 vcl/source/gdi/virdev.cxx              |   10 +++----
 vcl/source/outdev/bitmap.cxx           |    8 ++----
 vcl/source/outdev/clipping.cxx         |    2 -
 vcl/source/outdev/curvedshapes.cxx     |    8 +++---
 vcl/source/outdev/font.cxx             |   20 +++++++--------
 vcl/source/outdev/gradient.cxx         |    2 -
 vcl/source/outdev/hatch.cxx            |    2 -
 vcl/source/outdev/line.cxx             |    4 +--
 vcl/source/outdev/nativecontrols.cxx   |    8 +++---
 vcl/source/outdev/outdev.cxx           |   30 +++++++++++------------
 vcl/source/outdev/pixel.cxx            |   10 +++----
 vcl/source/outdev/polygon.cxx          |    8 +++---
 vcl/source/outdev/polyline.cxx         |    8 +++---
 vcl/source/outdev/rect.cxx             |    4 +--
 vcl/source/outdev/text.cxx             |   10 +++----
 vcl/source/outdev/textline.cxx         |    4 +--
 vcl/source/outdev/transparent.cxx      |    4 +--
 vcl/source/window/window.cxx           |    6 ++--
 vcl/source/window/window2.cxx          |    8 +++---
 27 files changed, 120 insertions(+), 124 deletions(-)

New commits:
commit 8708d30369685ba84a0b9c335fcaccd4814fa842
Author: Chris Sherlock <chris.sherlock79 at gmail.com>
Date:   Wed Apr 23 07:22:08 2014 +1000

    Rename OutputDevice::ImplGetGraphics to GetGraphics
    
    Change-Id: I4086978f2292538c458802a7fb56c0d3826f2def

diff --git a/include/vcl/outdev.hxx b/include/vcl/outdev.hxx
index defa3dd..901cfbe 100644
--- a/include/vcl/outdev.hxx
+++ b/include/vcl/outdev.hxx
@@ -56,7 +56,7 @@
         return;                             \
                                             \
     if ( !mpGraphics )                      \
-        if ( !ImplGetGraphics() )           \
+        if ( !AcquireGraphics() )           \
             return;                         \
                                             \
     if ( mbInitClipRegion )                 \
@@ -401,8 +401,8 @@ public:
 
      @returns SalGraphics instance.
      */
-    SAL_DLLPRIVATE SalGraphics const *ImplGetGraphics() const;
-    SAL_DLLPRIVATE SalGraphics*     ImplGetGraphics();
+    SAL_DLLPRIVATE SalGraphics const *GetGraphics() const;
+    SAL_DLLPRIVATE SalGraphics*       GetGraphics();
 
     /** Acquire a graphics device that the output device uses to draw on.
 
diff --git a/vcl/source/gdi/bitmap.cxx b/vcl/source/gdi/bitmap.cxx
index 2bd739e2..dee0722 100644
--- a/vcl/source/gdi/bitmap.cxx
+++ b/vcl/source/gdi/bitmap.cxx
@@ -1642,7 +1642,7 @@ Bitmap Bitmap::CreateDisplayBitmap( OutputDevice* pDisplay )
 {
     Bitmap aDispBmp( *this );
 
-    if( mpImpBmp && ( pDisplay->mpGraphics || pDisplay->ImplGetGraphics() ) )
+    if( mpImpBmp && ( pDisplay->mpGraphics || pDisplay->AcquireGraphics() ) )
     {
         ImpBitmap* pImpDispBmp = new ImpBitmap;
 
diff --git a/vcl/source/gdi/embeddedfontshelper.cxx b/vcl/source/gdi/embeddedfontshelper.cxx
index 05730b7..1eca07e 100644
--- a/vcl/source/gdi/embeddedfontshelper.cxx
+++ b/vcl/source/gdi/embeddedfontshelper.cxx
@@ -230,7 +230,7 @@ OUString EmbeddedFontsHelper::fontFileUrl( const OUString& familyName, FontFamil
         return url;
     }
     bool ok = false;
-    SalGraphics* graphics = Application::GetDefaultDevice()->ImplGetGraphics();
+    SalGraphics* graphics = Application::GetDefaultDevice()->GetGraphics();
     PhysicalFontCollection fonts;
     graphics->GetDevFontList( &fonts );
     boost::scoped_ptr< ImplGetDevFontList > fontInfo( fonts.GetDevFontList());
diff --git a/vcl/source/gdi/pdfwriter_impl.cxx b/vcl/source/gdi/pdfwriter_impl.cxx
index 9d00716..6dcaf0a 100644
--- a/vcl/source/gdi/pdfwriter_impl.cxx
+++ b/vcl/source/gdi/pdfwriter_impl.cxx
@@ -3835,7 +3835,7 @@ void PDFWriterImpl::appendBuiltinFontsToDict( OStringBuffer& rDict ) const
 
 bool PDFWriterImpl::emitFonts()
 {
-    if( ! m_pReferenceDevice->ImplGetGraphics() )
+    if( ! m_pReferenceDevice->AcquireGraphics() )
         return false;
 
     OStringBuffer aLine( 1024 );
@@ -7041,7 +7041,7 @@ void PDFWriterImpl::registerGlyphs( int nGlyphs,
                 rNewGlyph.m_nFontID = pMappedFontObjects[i];
                 rNewGlyph.m_nSubsetGlyphID = nNewId;
             }
-            getReferenceDevice()->ImplGetGraphics();
+            getReferenceDevice()->AcquireGraphics();
             const bool bVertical = ((pGlyphs[i] & GF_ROTMASK) != 0);
             pGlyphWidths[i] = m_aFontCache.getGlyphWidth( pCurrentFont,
                                                           nFontGlyphId,
@@ -7064,7 +7064,7 @@ void PDFWriterImpl::registerGlyphs( int nGlyphs,
 
             const Ucs2SIntMap* pEncoding = NULL;
             const Ucs2OStrMap* pNonEncoded = NULL;
-            getReferenceDevice()->ImplGetGraphics();
+            getReferenceDevice()->AcquireGraphics();
             pEncoding = m_pReferenceDevice->mpGraphics->GetFontEncodingVector( pCurrentFont, &pNonEncoded );
 
             Ucs2SIntMap::const_iterator enc_it;
diff --git a/vcl/source/gdi/print.cxx b/vcl/source/gdi/print.cxx
index f017ee6..47190ff 100644
--- a/vcl/source/gdi/print.cxx
+++ b/vcl/source/gdi/print.cxx
@@ -770,7 +770,7 @@ void Printer::ImplInit( SalPrinterQueueInfo* pInfo )
     }
 
     // we need a graphics
-    if ( !ImplGetGraphics() )
+    if ( !AcquireGraphics() )
     {
         ImplInitDisplay( NULL );
         return;
@@ -937,7 +937,7 @@ SalPrinterQueueInfo* Printer::ImplGetQueueInfo( const OUString& rPrinterName,
 void Printer::ImplUpdatePageData()
 {
     // we need a graphics
-    if ( !ImplGetGraphics() )
+    if ( !AcquireGraphics() )
         return;
 
     mpGraphics->GetResolution( mnDPIX, mnDPIY );
diff --git a/vcl/source/gdi/virdev.cxx b/vcl/source/gdi/virdev.cxx
index 17926b8..616c68b 100644
--- a/vcl/source/gdi/virdev.cxx
+++ b/vcl/source/gdi/virdev.cxx
@@ -133,7 +133,7 @@ void VirtualDevice::ImplInitVirDev( const OutputDevice* pOutDev,
 
     SalGraphics* pGraphics;
     if ( !pOutDev->mpGraphics )
-        ((OutputDevice*)pOutDev)->ImplGetGraphics();
+        pOutDev->AcquireGraphics();
     pGraphics = pOutDev->mpGraphics;
     if ( pGraphics )
         mpVirDev = pSVData->mpDefInst->CreateVirtualDevice( pGraphics, nDX, nDY, nBitCount, pData );
@@ -315,7 +315,7 @@ bool VirtualDevice::InnerImplSetOutputSizePixel( const Size& rNewSize, bool bEra
         // we need a graphics
         if ( !mpGraphics )
         {
-            if ( !ImplGetGraphics() )
+            if ( !AcquireGraphics() )
                 return false;
         }
 
@@ -422,7 +422,7 @@ void VirtualDevice::EnableRTL( bool bEnable )
     // under rare circumstances in the UI, eg the valueset control
     // because each virdev has its own SalGraphics we can safely switch the SalGraphics here
     // ...hopefully
-    if( ImplGetGraphics() )
+    if( AcquireGraphics() )
         mpGraphics->SetLayout( bEnable ? SAL_LAYOUT_BIDI_RTL : 0 );
 
     OutputDevice::EnableRTL(bEnable);
@@ -518,7 +518,7 @@ void VirtualDevice::ImplSetReferenceDevice( RefDevMode i_eRefDevMode, sal_Int32
         delete mpFontCache;
 
     // get font list with scalable fonts only
-    ImplGetGraphics();
+    AcquireGraphics();
     mpFontCollection = pSVData->maGDIData.mpScreenFontList->Clone( true, false );
 
     // prepare to use new font lists
diff --git a/vcl/source/outdev/bitmap.cxx b/vcl/source/outdev/bitmap.cxx
index 68e13c7..056af7e 100644
--- a/vcl/source/outdev/bitmap.cxx
+++ b/vcl/source/outdev/bitmap.cxx
@@ -886,7 +886,7 @@ Bitmap OutputDevice::GetBitmap( const Point& rSrcPt, const Size& rSize ) const
     long    nWidth = ImplLogicWidthToDevicePixel( rSize.Width() );
     long    nHeight = ImplLogicHeightToDevicePixel( rSize.Height() );
 
-    if ( mpGraphics || ( (OutputDevice*) this )->ImplGetGraphics() )
+    if ( mpGraphics || AcquireGraphics() )
     {
         if ( nWidth > 0 && nHeight  > 0 && nX <= (mnOutWidth + mnOutOffX) && nY <= (mnOutHeight + mnOutOffY))
         {
@@ -932,7 +932,7 @@ Bitmap OutputDevice::GetBitmap( const Point& rSrcPt, const Size& rSize ) const
 
                 if ( aVDev.SetOutputSizePixel( aRect.GetSize() ) )
                 {
-                    if ( ((OutputDevice*)&aVDev)->mpGraphics || ((OutputDevice*)&aVDev)->ImplGetGraphics() )
+                    if ( ((OutputDevice*)&aVDev)->mpGraphics || ((OutputDevice*)&aVDev)->AcquireGraphics() )
                     {
                         SalTwoRect aPosAry;
 
diff --git a/vcl/source/outdev/curvedshapes.cxx b/vcl/source/outdev/curvedshapes.cxx
index 160d06b..c07c19f 100644
--- a/vcl/source/outdev/curvedshapes.cxx
+++ b/vcl/source/outdev/curvedshapes.cxx
@@ -46,7 +46,7 @@ void OutputDevice::DrawEllipse( const Rectangle& rRect )
     // we need a graphics
     if ( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
     }
 
@@ -93,7 +93,7 @@ void OutputDevice::DrawArc( const Rectangle& rRect,
     // we need a graphics
     if ( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
     }
 
@@ -136,7 +136,7 @@ void OutputDevice::DrawPie( const Rectangle& rRect,
     // we need a graphics
     if ( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
     }
 
@@ -186,7 +186,7 @@ void OutputDevice::DrawChord( const Rectangle& rRect,
     // we need a graphics
     if ( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
     }
 
diff --git a/vcl/source/outdev/font.cxx b/vcl/source/outdev/font.cxx
index ceea7a9..b83f7df 100644
--- a/vcl/source/outdev/font.cxx
+++ b/vcl/source/outdev/font.cxx
@@ -172,7 +172,7 @@ void OutputDevice::ImplClearFontData( const bool bNewFontLists )
         }
 
         // release all physically selected fonts on this device
-        if( ImplGetGraphics() )
+        if( AcquireGraphics() )
             mpGraphics->ReleaseFonts();
     }
 
@@ -186,7 +186,7 @@ void OutputDevice::ImplClearFontData( const bool bNewFontLists )
         if ( bNewFontLists )
         {
             // we need a graphics
-            if ( ImplGetGraphics() )
+            if ( AcquireGraphics() )
             {
                 if( mpFontCollection && mpFontCollection != pSVData->maGDIData.mpScreenFontList )
                     mpFontCollection->Clear();
@@ -225,7 +225,7 @@ void OutputDevice::ImplRefreshFontData( const bool bNewFontLists )
         if ( bNewFontLists )
         {
             // we need a graphics
-            if ( ImplGetGraphics() )
+            if ( AcquireGraphics() )
             {
                 if( mpPDFWriter )
                 {
@@ -272,7 +272,7 @@ void OutputDevice::ImplUpdateAllFontData( bool bNewFontLists )
         Window * pFrame = pSVData->maWinData.mpFirstFrame;
         if ( pFrame )
         {
-            if ( pFrame->ImplGetGraphics() )
+            if ( pFrame->AcquireGraphics() )
             {
                 // Stupid typecast here and somewhere ((OutputDevice*)&aVDev)->, because bug in .NET2002 compiler
                 OutputDevice *pDevice = (OutputDevice*)pFrame;
@@ -1131,7 +1131,7 @@ void OutputDevice::ImplInitFontList() const
 {
     if( !mpFontCollection->Count() )
     {
-        if( mpGraphics || ImplGetGraphics() )
+        if( mpGraphics || AcquireGraphics() )
         {
             SAL_INFO( "vcl.gdi", "OutputDevice::ImplInitFontList()" );
             mpGraphics->GetDevFontList( mpFontCollection );
@@ -1192,7 +1192,7 @@ bool OutputDevice::ImplNewFont() const
         return true;
 
     // we need a graphics
-    if ( !mpGraphics && !ImplGetGraphics() )
+    if ( !mpGraphics && !AcquireGraphics() )
         return false;
     SalGraphics* pGraphics = mpGraphics;
     ImplInitFontList();
@@ -2087,7 +2087,7 @@ bool OutputDevice::AddTempDevFont( const OUString& rFileURL, const OUString& rFo
 
     ImplInitFontList();
 
-    if( !mpGraphics && !ImplGetGraphics() )
+    if( !mpGraphics && !AcquireGraphics() )
         return false;
 
     bool bRC = mpGraphics->AddTempDevFont( mpFontCollection, rFileURL, rFontName );
@@ -2225,7 +2225,7 @@ SystemFontData OutputDevice::GetSysFontData(int nFallbacklevel) const
     SystemFontData aSysFontData;
     aSysFontData.nSize = sizeof(aSysFontData);
 
-    if (!mpGraphics) ImplGetGraphics();
+    if (!mpGraphics) AcquireGraphics();
     if (mpGraphics) aSysFontData = mpGraphics->GetSysFontData(nFallbacklevel);
 
     return aSysFontData;
@@ -2299,7 +2299,7 @@ bool OutputDevice::GetGlyphBoundRects( const Point& rOrigin, const OUString& rSt
 bool OutputDevice::GetFontCapabilities( FontCapabilities& rFontCapabilities ) const
 {
     // we need a graphics
-    if( !mpGraphics && !ImplGetGraphics() )
+    if( !mpGraphics && !AcquireGraphics() )
         return false;
 
     if( mbNewFont )
@@ -2317,7 +2317,7 @@ bool OutputDevice::GetFontCharMap( FontCharMap& rFontCharMap ) const
     rFontCharMap.Reset();
 
     // we need a graphics
-    if( !mpGraphics && !ImplGetGraphics() )
+    if( !mpGraphics && !AcquireGraphics() )
         return false;
 
     if( mbNewFont )
diff --git a/vcl/source/outdev/gradient.cxx b/vcl/source/outdev/gradient.cxx
index 9df5917..2357f5e 100644
--- a/vcl/source/outdev/gradient.cxx
+++ b/vcl/source/outdev/gradient.cxx
@@ -108,7 +108,7 @@ void OutputDevice::DrawGradient( const PolyPolygon& rPolyPoly,
             // do nothing if the rectangle is empty
             if ( !aRect.IsEmpty() )
             {
-                if( !mpGraphics && !ImplGetGraphics() )
+                if( !mpGraphics && !AcquireGraphics() )
                     return;
 
                 // secure clip region
diff --git a/vcl/source/outdev/hatch.cxx b/vcl/source/outdev/hatch.cxx
index f89a004..5d313b52 100644
--- a/vcl/source/outdev/hatch.cxx
+++ b/vcl/source/outdev/hatch.cxx
@@ -82,7 +82,7 @@ void OutputDevice::DrawHatch( const PolyPolygon& rPolyPoly, const Hatch& rHatch
     if( !IsDeviceOutputNecessary() || ImplIsRecordLayout() )
         return;
 
-    if( !mpGraphics && !ImplGetGraphics() )
+    if( !mpGraphics && !AcquireGraphics() )
         return;
 
     if( mbInitClipRegion )
diff --git a/vcl/source/outdev/line.cxx b/vcl/source/outdev/line.cxx
index c6e9a86..13f1d65 100644
--- a/vcl/source/outdev/line.cxx
+++ b/vcl/source/outdev/line.cxx
@@ -49,7 +49,7 @@ void OutputDevice::DrawLine( const Point& rStartPt, const Point& rEndPt,
 
     if( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
     }
 
@@ -96,7 +96,7 @@ void OutputDevice::DrawLine( const Point& rStartPt, const Point& rEndPt )
 
     if ( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
     }
 
diff --git a/vcl/source/outdev/nativecontrols.cxx b/vcl/source/outdev/nativecontrols.cxx
index 2a78cce..b4f35a2 100644
--- a/vcl/source/outdev/nativecontrols.cxx
+++ b/vcl/source/outdev/nativecontrols.cxx
@@ -146,7 +146,7 @@ bool OutputDevice::IsNativeControlSupported( ControlType nType, ControlPart nPar
         return false;
 
     if ( !mpGraphics )
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return false;
 
     return( mpGraphics->IsNativeControlSupported(nType, nPart) );
@@ -162,7 +162,7 @@ bool OutputDevice::HitTestNativeControl( ControlType nType,
         return false;
 
     if ( !mpGraphics )
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return false;
 
     Point aWinOffs( mnOutOffX, mnOutOffY );
@@ -263,7 +263,7 @@ bool OutputDevice::DrawNativeControl( ControlType nType,
 
     // make sure the current clip region is initialized correctly
     if ( !mpGraphics )
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return false;
 
     if ( mbInitClipRegion )
@@ -304,7 +304,7 @@ bool OutputDevice::GetNativeControlRegion(  ControlType nType,
         return false;
 
     if ( !mpGraphics )
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return false;
 
     // Convert the coordinates from relative to Window-absolute, so we draw
diff --git a/vcl/source/outdev/outdev.cxx b/vcl/source/outdev/outdev.cxx
index 56c27ca..7b81420 100644
--- a/vcl/source/outdev/outdev.cxx
+++ b/vcl/source/outdev/outdev.cxx
@@ -164,7 +164,7 @@ static void ImplDeleteObjStack( ImplObjStack* pObjStack )
 bool OutputDevice::ImplIsAntiparallel() const
 {
     bool bRet = false;
-    if( ImplGetGraphics() )
+    if( AcquireGraphics() )
     {
         if( ( (mpGraphics->GetLayout() & SAL_LAYOUT_BIDI_RTL) && ! IsRTLEnabled() ) ||
             ( ! (mpGraphics->GetLayout() & SAL_LAYOUT_BIDI_RTL) && IsRTLEnabled() ) )
@@ -324,7 +324,7 @@ OutputDevice::~OutputDevice()
 bool OutputDevice::supportsOperation( OutDevSupportType eType ) const
 {
     if( !mpGraphics )
-        if( !ImplGetGraphics() )
+        if( !AcquireGraphics() )
             return false;
     const bool bHasSupport = mpGraphics->supportsOperation( eType );
     return bHasSupport;
@@ -340,7 +340,7 @@ void OutputDevice::EnableRTL( bool bEnable )
 
 bool OutputDevice::HasMirroredGraphics() const
 {
-   return ( ImplGetGraphics() && (mpGraphics->GetLayout() & SAL_LAYOUT_BIDI_RTL) );
+   return ( AcquireGraphics() && (mpGraphics->GetLayout() & SAL_LAYOUT_BIDI_RTL) );
 }
 
 // note: the coordiantes to be remirrored are in frame coordiantes !
@@ -376,7 +376,7 @@ void    OutputDevice::ReMirror( Region &rRegion ) const
 
 }
 
-SalGraphics* OutputDevice::ImplGetGraphics()
+SalGraphics* OutputDevice::GetGraphics()
 {
     DBG_TESTSOLARMUTEX();
 
@@ -391,7 +391,7 @@ SalGraphics* OutputDevice::ImplGetGraphics()
     return mpGraphics;
 }
 
-SalGraphics const *OutputDevice::ImplGetGraphics() const
+SalGraphics const *OutputDevice::GetGraphics() const
 {
     DBG_TESTSOLARMUTEX();
 
@@ -496,7 +496,7 @@ void OutputDevice::ImplDrawOutDevDirect( const OutputDevice* pSrcDev, SalTwoRect
         {
             if ( !pSrcDev->mpGraphics )
             {
-                if ( !((OutputDevice*)pSrcDev)->ImplGetGraphics() )
+                if ( !((OutputDevice*)pSrcDev)->AcquireGraphics() )
                     return;
             }
             pGraphics2 = pSrcDev->mpGraphics;
@@ -509,14 +509,14 @@ void OutputDevice::ImplDrawOutDevDirect( const OutputDevice* pSrcDev, SalTwoRect
             {
                 if ( !pSrcDev->mpGraphics )
                 {
-                    if ( !((OutputDevice*)pSrcDev)->ImplGetGraphics() )
+                    if ( !((OutputDevice*)pSrcDev)->AcquireGraphics() )
                         return;
                 }
                 pGraphics2 = pSrcDev->mpGraphics;
 
                 if ( !mpGraphics )
                 {
-                    if ( !ImplGetGraphics() )
+                    if ( !AcquireGraphics() )
                         return;
                 }
                 DBG_ASSERT( mpGraphics && pSrcDev->mpGraphics,
@@ -720,7 +720,7 @@ void OutputDevice::ImplDrawFrameDev( const Point& rPt, const Point& rDevPt, cons
 
     if ( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
     }
 
@@ -801,7 +801,7 @@ void OutputDevice::SetRasterOp( RasterOp eRasterOp )
         meRasterOp = eRasterOp;
         mbInitLineColor = mbInitFillColor = true;
 
-        if( mpGraphics || ImplGetGraphics() )
+        if( mpGraphics || AcquireGraphics() )
             mpGraphics->SetXORMode( (ROP_INVERT == meRasterOp) || (ROP_XOR == meRasterOp), ROP_INVERT == meRasterOp );
     }
 
@@ -1196,7 +1196,7 @@ sal_uInt16 OutputDevice::GetBitCount() const
     // we need a graphics instance
     if ( !mpGraphics )
     {
-        if ( !((OutputDevice*)this)->ImplGetGraphics() )
+        if ( !((OutputDevice*)this)->AcquireGraphics() )
             return 0;
     }
 
@@ -1230,7 +1230,7 @@ SystemGraphicsData OutputDevice::GetSystemGfxData() const
 {
     if ( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return SystemGraphicsData();
     }
 
@@ -1316,7 +1316,7 @@ bool OutputDevice::DrawEPS( const Point& rPoint, const Size& rSize,
         // draw the real EPS graphics
         if( rGfxLink.GetData() && rGfxLink.GetDataSize() )
         {
-            if( !mpGraphics && !ImplGetGraphics() )
+            if( !mpGraphics && !AcquireGraphics() )
                 return bDrawn;
 
             if( mbInitClipRegion )
diff --git a/vcl/source/outdev/pixel.cxx b/vcl/source/outdev/pixel.cxx
index 5da1ca3..3375eb2 100644
--- a/vcl/source/outdev/pixel.cxx
+++ b/vcl/source/outdev/pixel.cxx
@@ -51,10 +51,10 @@ Color OutputDevice::GetPixel( const Point& rPt ) const
 
     Color aColor;
 
-    if ( mpGraphics || ((OutputDevice*)this)->ImplGetGraphics() )
+    if ( mpGraphics || AcquireGraphics() )
     {
         if ( mbInitClipRegion )
-            ((OutputDevice*)this)->ImplInitClipRegion();
+            const_cast<OutputDevice*>(this)->ImplInitClipRegion();
 
         if ( !mbOutputClipped )
         {
@@ -82,7 +82,7 @@ void OutputDevice::DrawPixel( const Point& rPt )
 
     if ( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
     }
 
@@ -115,7 +115,7 @@ void OutputDevice::DrawPixel( const Point& rPt, const Color& rColor )
 
     if ( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
     }
 
@@ -149,7 +149,7 @@ void OutputDevice::DrawPixel( const Polygon& rPts, const Color* pColors )
             if ( !IsDeviceOutputNecessary() || ImplIsRecordLayout() )
                 return;
 
-            if ( mpGraphics || ImplGetGraphics() )
+            if ( mpGraphics || AcquireGraphics() )
             {
                 if ( mbInitClipRegion )
                     ImplInitClipRegion();
diff --git a/vcl/source/outdev/polygon.cxx b/vcl/source/outdev/polygon.cxx
index 3598186..722386a 100644
--- a/vcl/source/outdev/polygon.cxx
+++ b/vcl/source/outdev/polygon.cxx
@@ -47,7 +47,7 @@ void OutputDevice::DrawPolyPolygon( const PolyPolygon& rPolyPoly )
 
     // we need a graphics
     if ( !mpGraphics )
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
 
     if ( mbInitClipRegion )
@@ -154,7 +154,7 @@ void OutputDevice::DrawPolygon( const Polygon& rPoly )
 
     // we need a graphics
     if ( !mpGraphics )
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
 
     if ( mbInitClipRegion )
@@ -254,7 +254,7 @@ void OutputDevice::ImplDrawPolyPolygonWithB2DPolyPolygon(const basegfx::B2DPolyP
 
     // we need a graphics
     if( !mpGraphics )
-        if( !ImplGetGraphics() )
+        if( !AcquireGraphics() )
             return;
 
     if( mbInitClipRegion )
@@ -486,7 +486,7 @@ void OutputDevice::DrawGrid( const Rectangle& rRect, const Size& rDist, sal_uLon
     if( aDstRect.IsEmpty() || ImplIsRecordLayout() )
         return;
 
-    if( !mpGraphics && !ImplGetGraphics() )
+    if( !mpGraphics && !AcquireGraphics() )
         return;
 
     if( mbInitClipRegion )
diff --git a/vcl/source/outdev/polyline.cxx b/vcl/source/outdev/polyline.cxx
index 3d06e27..fe3e9cd 100644
--- a/vcl/source/outdev/polyline.cxx
+++ b/vcl/source/outdev/polyline.cxx
@@ -41,7 +41,7 @@ void OutputDevice::DrawPolyLine( const Polygon& rPoly )
 
     // we need a graphics
     if ( !mpGraphics )
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
 
     if ( mbInitClipRegion )
@@ -150,7 +150,7 @@ void OutputDevice::DrawPolyLine(
 
     // we need a graphics
     if( !mpGraphics )
-        if( !ImplGetGraphics() )
+        if( !AcquireGraphics() )
             return;
 
     if( mbInitClipRegion )
@@ -239,7 +239,7 @@ void OutputDevice::DrawPolyLineWithLineInfo(const Polygon& rPoly, const LineInfo
     Polygon aPoly = ImplLogicToDevicePixel( rPoly );
 
     // we need a graphics
-    if ( !mpGraphics && !ImplGetGraphics() )
+    if ( !mpGraphics && !AcquireGraphics() )
         return;
 
     if ( mbInitClipRegion )
@@ -330,7 +330,7 @@ bool OutputDevice::TryDrawPolyLineDirect(
 
     // we need a graphics
     if( !mpGraphics )
-        if( !ImplGetGraphics() )
+        if( !AcquireGraphics() )
             return false;
 
     if( mbInitClipRegion )
diff --git a/vcl/source/outdev/rect.cxx b/vcl/source/outdev/rect.cxx
index 34abf0a..d47119b 100644
--- a/vcl/source/outdev/rect.cxx
+++ b/vcl/source/outdev/rect.cxx
@@ -42,7 +42,7 @@ void OutputDevice::DrawRect( const Rectangle& rRect )
 
     if ( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
     }
 
@@ -83,7 +83,7 @@ void OutputDevice::DrawRect( const Rectangle& rRect,
     // we need a graphics
     if ( !mpGraphics )
     {
-        if ( !ImplGetGraphics() )
+        if ( !AcquireGraphics() )
             return;
     }
 
diff --git a/vcl/source/outdev/text.cxx b/vcl/source/outdev/text.cxx
index 246d9d4..f54c989 100644
--- a/vcl/source/outdev/text.cxx
+++ b/vcl/source/outdev/text.cxx
@@ -1023,7 +1023,7 @@ void OutputDevice::DrawTextArray( const Point& rStartPt, const OUString& rStr,
 
     if ( !IsDeviceOutputNecessary() )
         return;
-    if( !mpGraphics && !ImplGetGraphics() )
+    if( !mpGraphics && !AcquireGraphics() )
         return;
     if( mbInitClipRegion )
         ImplInitClipRegion();
@@ -1307,7 +1307,7 @@ SalLayout* OutputDevice::ImplLayout(const OUString& rOrigStr,
 {
     // we need a graphics
     if( !mpGraphics )
-        if( !ImplGetGraphics() )
+        if( !AcquireGraphics() )
             return NULL;
 
     // initialize font if needed
@@ -1767,7 +1767,7 @@ void OutputDevice::AddTextRectActions( const Rectangle& rRect,
         return;
 
     // we need a graphics
-    if( !mpGraphics && !ImplGetGraphics() )
+    if( !mpGraphics && !AcquireGraphics() )
         return;
     if( mbInitClipRegion )
         ImplInitClipRegion();
@@ -1808,7 +1808,7 @@ void OutputDevice::DrawText( const Rectangle& rRect, const OUString& rOrigStr, s
         return;
 
     // we need a graphics
-    if( !mpGraphics && !ImplGetGraphics() )
+    if( !mpGraphics && !AcquireGraphics() )
         return;
     if( mbInitClipRegion )
         ImplInitClipRegion();
@@ -2115,7 +2115,7 @@ void OutputDevice::DrawCtrlText( const Point& rPos, const OUString& rStr,
 
     // better get graphics here because ImplDrawMnemonicLine() will not
     // we need a graphics
-    if( !mpGraphics && !ImplGetGraphics() )
+    if( !mpGraphics && !AcquireGraphics() )
         return;
     if( mbInitClipRegion )
         ImplInitClipRegion();
diff --git a/vcl/source/outdev/textline.cxx b/vcl/source/outdev/textline.cxx
index 7257eb0..ad173ad 100644
--- a/vcl/source/outdev/textline.cxx
+++ b/vcl/source/outdev/textline.cxx
@@ -971,7 +971,7 @@ void OutputDevice::DrawTextLine( const Point& rPos, long nWidth,
         return;
 
     // we need a graphics
-    if( !mpGraphics && !ImplGetGraphics() )
+    if( !mpGraphics && !AcquireGraphics() )
         return;
     if( mbInitClipRegion )
         ImplInitClipRegion();
@@ -1003,7 +1003,7 @@ void OutputDevice::DrawWaveLine( const Point& rStartPos, const Point& rEndPos )
 
     // we need a graphics
     if( !mpGraphics )
-        if( !ImplGetGraphics() )
+        if( !AcquireGraphics() )
             return;
 
     if ( mbInitClipRegion )
diff --git a/vcl/source/outdev/transparent.cxx b/vcl/source/outdev/transparent.cxx
index acf9464..e035fa9 100644
--- a/vcl/source/outdev/transparent.cxx
+++ b/vcl/source/outdev/transparent.cxx
@@ -187,7 +187,7 @@ void OutputDevice::DrawTransparent( const basegfx::B2DPolyPolygon& rB2DPolyPoly,
 
     // we need a graphics
     if( !mpGraphics )
-        if( !ImplGetGraphics() )
+        if( !AcquireGraphics() )
             return;
 
     if( mbInitClipRegion )
@@ -561,7 +561,7 @@ void OutputDevice::DrawTransparent( const PolyPolygon& rPolyPoly,
 
     // get the device graphics as drawing target
     if( !mpGraphics )
-        if( !ImplGetGraphics() )
+        if( !AcquireGraphics() )
             return;
 
     // try hard to draw it directly, because the emulation layers are slower
diff --git a/vcl/source/window/window.cxx b/vcl/source/window/window.cxx
index d44b2fd..0de07b0 100644
--- a/vcl/source/window/window.cxx
+++ b/vcl/source/window/window.cxx
@@ -1081,7 +1081,7 @@ void Window::ImplInit( Window* pParent, WinBits nStyle, SystemParentData* pSyste
         else
         {
             OutputDevice *pOutDev = GetOutDev();
-            if ( pOutDev->ImplGetGraphics() )
+            if ( pOutDev->AcquireGraphics() )
             {
                 mpGraphics->GetResolution( mpWindowImpl->mpFrameData->mnDPIX, mpWindowImpl->mpFrameData->mnDPIY );
             }
@@ -1526,7 +1526,7 @@ SalGraphics* Window::ImplGetFrameGraphics() const
     else
     {
         OutputDevice *pFrameWinOutDev = mpWindowImpl->mpFrameWindow;
-        pFrameWinOutDev->ImplGetGraphics();
+        pFrameWinOutDev->AcquireGraphics();
     }
     mpWindowImpl->mpFrameWindow->mpGraphics->ResetClipRegion();
     return mpWindowImpl->mpFrameWindow->mpGraphics;
diff --git a/vcl/source/window/window2.cxx b/vcl/source/window/window2.cxx
index e2330a9..1567aed 100644
--- a/vcl/source/window/window2.cxx
+++ b/vcl/source/window/window2.cxx
@@ -372,7 +372,7 @@ void Window::Invert( const Rectangle& rRect, sal_uInt16 nFlags )
     // we need a graphics
     if ( !mpGraphics )
     {
-        if ( !pOutDev->ImplGetGraphics() )
+        if ( !pOutDev->AcquireGraphics() )
             return;
     }
 
@@ -406,7 +406,7 @@ void Window::Invert( const Polygon& rPoly, sal_uInt16 nFlags )
     // we need a graphics
     if ( !mpGraphics )
     {
-        if ( !pOutDev->ImplGetGraphics() )
+        if ( !pOutDev->AcquireGraphics() )
             return;
     }
 
@@ -481,7 +481,7 @@ void Window::InvertTracking( const Rectangle& rRect, sal_uInt16 nFlags )
         // we need a graphics
         if ( !mpGraphics )
         {
-            if ( !pOutDev->ImplGetGraphics() )
+            if ( !pOutDev->AcquireGraphics() )
                 return;
         }
 
@@ -545,7 +545,7 @@ void Window::InvertTracking( const Polygon& rPoly, sal_uInt16 nFlags )
         // we need a graphics
         if ( !mpGraphics )
         {
-            if ( !pOutDev->ImplGetGraphics() )
+            if ( !pOutDev->AcquireGraphics() )
                 return;
         }
 
commit 665bc42d7504c3896a485c8bab17b8eff7d119df
Author: Chris Sherlock <chris.sherlock79 at gmail.com>
Date:   Wed Apr 23 00:57:50 2014 +1000

    Rename VCL's ImplInitGraphics to AcquireGraphics
    
    Turns out, we don't try to initialize a graphics context, much less
    *acquire* one. e.g. Window instances can have many frames (subwindows),
    of which one some are really being used at any time so we try to
    "steal" one of the graphics contexts from the frame to use ourself,
    later on that frame will steal it from someone else, etc.
    
    Change-Id: I66d5dbb7015301bc2d2be51627061c91e1f2ee5d

diff --git a/include/vcl/print.hxx b/include/vcl/print.hxx
index b02f739..58651d5 100644
--- a/include/vcl/print.hxx
+++ b/include/vcl/print.hxx
@@ -230,7 +230,7 @@ private:
     bool                        mbIsQueuePrinter;
     Link                        maErrorHdl;
 
-    bool                        ImplInitGraphics() const SAL_OVERRIDE;
+    bool                        AcquireGraphics() const SAL_OVERRIDE;
     void                        ImplReleaseGraphics( bool bRelease = true ) SAL_OVERRIDE;
     void                        ImplReleaseFonts() SAL_OVERRIDE;
     SAL_DLLPRIVATE void         ImplInitData();
diff --git a/include/vcl/virdev.hxx b/include/vcl/virdev.hxx
index 072b94d..6b1af90 100644
--- a/include/vcl/virdev.hxx
+++ b/include/vcl/virdev.hxx
@@ -61,7 +61,7 @@ private:
     SAL_DLLPRIVATE bool ForceZeroExtleadBug() const
         { return ((meRefDevMode & REFDEV_FORCE_ZERO_EXTLEAD) != 0); }
 public:
-    bool ImplInitGraphics() const SAL_OVERRIDE;
+    bool AcquireGraphics() const SAL_OVERRIDE;
     void ImplReleaseGraphics( bool bRelease = true ) SAL_OVERRIDE;
 
 public:
diff --git a/include/vcl/window.hxx b/include/vcl/window.hxx
index 25063dc..d8d8855 100644
--- a/include/vcl/window.hxx
+++ b/include/vcl/window.hxx
@@ -375,7 +375,7 @@ private:
     friend Window* ImplFindWindow( const SalFrame* pFrame, Point& rSalFramePos );
 public:
     SAL_DLLPRIVATE void                ImplInit( Window* pParent, WinBits nStyle, SystemParentData* pSystemParentData );
-    bool                               ImplInitGraphics() const SAL_OVERRIDE;
+    bool                               AcquireGraphics() const SAL_OVERRIDE;
     void                               ImplReleaseGraphics( bool bRelease = true ) SAL_OVERRIDE;
     SAL_DLLPRIVATE WinBits             ImplInitRes( const ResId& rResId );
     SAL_DLLPRIVATE WindowResHeader     ImplLoadResHeader( const ResId& rResId );
diff --git a/vcl/source/gdi/print.cxx b/vcl/source/gdi/print.cxx
index 5b571d9..f017ee6 100644
--- a/vcl/source/gdi/print.cxx
+++ b/vcl/source/gdi/print.cxx
@@ -574,7 +574,7 @@ void Printer::ImplInitData()
     pSVData->maGDIData.mpFirstPrinter = this;
 }
 
-bool Printer::ImplInitGraphics() const
+bool Printer::AcquireGraphics() const
 {
     DBG_TESTSOLARMUTEX();
 
diff --git a/vcl/source/gdi/virdev.cxx b/vcl/source/gdi/virdev.cxx
index be348ec..17926b8 100644
--- a/vcl/source/gdi/virdev.cxx
+++ b/vcl/source/gdi/virdev.cxx
@@ -34,7 +34,7 @@
 
 using namespace ::com::sun::star::uno;
 
-bool VirtualDevice::ImplInitGraphics() const
+bool VirtualDevice::AcquireGraphics() const
 {
     DBG_TESTSOLARMUTEX();
 
diff --git a/vcl/source/outdev/clipping.cxx b/vcl/source/outdev/clipping.cxx
index 7da8152..257bd58 100644
--- a/vcl/source/outdev/clipping.cxx
+++ b/vcl/source/outdev/clipping.cxx
@@ -74,7 +74,7 @@ bool OutputDevice::ImplSelectClipRegion( const Region& rRegion, SalGraphics* pGr
     if( !pGraphics )
     {
         if( !mpGraphics )
-            if( !ImplInitGraphics() )
+            if( !AcquireGraphics() )
                 return false;
         pGraphics = mpGraphics;
     }
diff --git a/vcl/source/outdev/outdev.cxx b/vcl/source/outdev/outdev.cxx
index 4cfbad8..56c27ca 100644
--- a/vcl/source/outdev/outdev.cxx
+++ b/vcl/source/outdev/outdev.cxx
@@ -382,7 +382,7 @@ SalGraphics* OutputDevice::ImplGetGraphics()
 
     if ( !mpGraphics )
     {
-        if ( !ImplInitGraphics() )
+        if ( !AcquireGraphics() )
         {
             SAL_WARN("vcl", "No mpGraphics set");
         }
@@ -397,7 +397,7 @@ SalGraphics const *OutputDevice::ImplGetGraphics() const
 
     if ( !mpGraphics )
     {
-        if ( !ImplInitGraphics() )
+        if ( !AcquireGraphics() )
         {
             SAL_WARN("vcl", "No mpGraphics set");
         }
diff --git a/vcl/source/window/window.cxx b/vcl/source/window/window.cxx
index eccb70e..d44b2fd 100644
--- a/vcl/source/window/window.cxx
+++ b/vcl/source/window/window.cxx
@@ -339,7 +339,7 @@ const char* ImplDbgCheckWindow( const void* pObj )
 }
 #endif
 
-bool Window::ImplInitGraphics() const
+bool Window::AcquireGraphics() const
 {
     DBG_TESTSOLARMUTEX();
 
commit 704e5abbe99b41859bb02d816ea1dc439180a5f6
Author: Chris Sherlock <chris.sherlock79 at gmail.com>
Date:   Wed Apr 23 00:51:39 2014 +1000

    Move bitmap functions in header, warn if calling GetBitmap() in Printer
    
    Change-Id: Id2325822730d3d9167706c8c4118eaa3ca727195

diff --git a/include/vcl/outdev.hxx b/include/vcl/outdev.hxx
index 57c32f2..990c47a 100644
--- a/include/vcl/outdev.hxx
+++ b/include/vcl/outdev.hxx
@@ -544,19 +544,13 @@ public:
     SAL_DLLPRIVATE void         ImplDrawBitmapWallpaper( long nX, long nY, long nWidth, long nHeight, const Wallpaper& rWallpaper );
     ///@}
 
-    /** @name Bitmap functions
-     */
-    ///@{
     SAL_DLLPRIVATE void         ImplDrawOutDevDirect ( const OutputDevice* pSrcDev, SalTwoRect& rPosAry );
-    SAL_DLLPRIVATE void         DrawAlphaBitmap      ( const Bitmap& rBmp, const AlphaMask& rAlpha,
-                                                       const Point& rDestPt, const Size& rDestSize,
-                                                       const Point& rSrcPtPixel, const Size& rSrcSizePixel );
+
     virtual void                ClipToPaintRegion    ( Rectangle& rDstRect );
     SAL_DLLPRIVATE void         ImplPrintTransparent ( const Bitmap& rBmp, const Bitmap& rMask,
                                                        const Point& rDestPt, const Size& rDestSize,
                                                        const Point& rSrcPtPixel, const Size& rSrcSizePixel );
     SAL_DLLPRIVATE Color        ImplDrawModeToColor  ( const Color& rColor ) const;
-    ///@}
 
     /** @name Frame functions
      */
@@ -861,6 +855,13 @@ public:
                                     const Image& rImage,
                                     sal_uInt16 nStyle = 0 );
 
+
+    virtual Bitmap              GetBitmap( const Point& rSrcPt, const Size& rSize ) const;
+
+    /** Query extended bitmap (with alpha channel, if available).
+     */
+    BitmapEx                    GetBitmapEx( const Point& rSrcPt, const Size& rSize ) const;
+
     /** Retrieve downsampled and cropped bitmap
 
         @attention This method ignores negative rDstSz values, thus
@@ -926,6 +927,15 @@ protected:
                                     const Point& rSrcPtPixel, const Size& rSrcSizePixel,
                                     BitmapEx& rBitmapEx );
 private:
+
+    SAL_DLLPRIVATE void         DrawAlphaBitmap(
+                                    const Bitmap& rBmp,
+                                    const AlphaMask& rAlpha,
+                                    const Point& rDestPt,
+                                    const Size& rDestSize,
+                                    const Point& rSrcPtPixel,
+                                    const Size& rSrcSizePixel );
+
     SAL_DLLPRIVATE Bitmap       BlendBitmap(
                                     Bitmap              aBmp,
                                     BitmapReadAccess*   pP,
@@ -1503,12 +1513,6 @@ public:
 
     Color                       GetPixel( const Point& rPt ) const;
 
-    Bitmap                      GetBitmap( const Point& rSrcPt, const Size& rSize ) const;
-
-    /** Query extended bitmap (with alpha channel, if available).
-     */
-    BitmapEx                    GetBitmapEx( const Point& rSrcPt, const Size& rSize ) const;
-
     // Enabling/disabling RTL only makes sense for OutputDevices that use a mirroring SalGraphisLayout
     virtual void                EnableRTL( bool bEnable = true);
     bool                        IsRTLEnabled() const { return mbEnableRTL; }
diff --git a/include/vcl/print.hxx b/include/vcl/print.hxx
index c29f845..b02f739 100644
--- a/include/vcl/print.hxx
+++ b/include/vcl/print.hxx
@@ -51,9 +51,6 @@ namespace vcl {
 }
 
 
-// - Printer-Types -
-
-
 #define PAGEQUEUE_ALLPAGES   0xFFFF
 
 enum PrinterSupport { SUPPORT_SET_ORIENTATION, SUPPORT_SET_PAPERBIN,
@@ -62,9 +59,6 @@ enum PrinterSupport { SUPPORT_SET_ORIENTATION, SUPPORT_SET_PAPERBIN,
                       SUPPORT_SETUPDIALOG, SUPPORT_FAX, SUPPORT_PDF };
 
 
-// - PrinterPage -
-
-
 class VCL_DLLPUBLIC PrinterPage
 {
     GDIMetaFile*    mpMtf;
@@ -85,9 +79,6 @@ public:
 
 
 
-// - QueueInfo -
-
-
 class VCL_DLLPUBLIC QueueInfo
 {
     friend class Printer;
@@ -119,9 +110,6 @@ public:
 };
 
 
-// - PrinterOptions -
-
-
 enum PrinterTransparencyMode
 {
     PRINTER_TRANSPARENCY_AUTO = 0,
@@ -208,9 +196,6 @@ public:
 };
 
 
-// - Printer -
-
-
 class VCL_DLLPUBLIC Printer : public OutputDevice
 {
     friend class OutputDevice;
@@ -278,6 +263,7 @@ protected:
 
 public:
     void                        DrawGradientEx( OutputDevice* pOut, const Rectangle& rRect, const Gradient& rGradient );
+    virtual Bitmap              GetBitmap( const Point& rSrcPt, const Size& rSize ) const SAL_OVERRIDE;
 
 protected:
 
diff --git a/vcl/source/gdi/print.cxx b/vcl/source/gdi/print.cxx
index b3daa80..5b571d9 100644
--- a/vcl/source/gdi/print.cxx
+++ b/vcl/source/gdi/print.cxx
@@ -1844,4 +1844,12 @@ void Printer::DrawImage( const Point&, const Size&, const Image&, sal_uInt16 )
     assert(false);
 }
 
+
+Bitmap Printer::GetBitmap( const Point& rSrcPt, const Size& rSize ) const
+{
+    SAL_WARN("vcl.gdi", "GetBitmap(): This should never be called on by a Printer instance");
+
+    return OutputDevice::GetBitmap( rSrcPt, rSize );
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/vcl/source/outdev/bitmap.cxx b/vcl/source/outdev/bitmap.cxx
index 019fe99..68e13c7 100644
--- a/vcl/source/outdev/bitmap.cxx
+++ b/vcl/source/outdev/bitmap.cxx
@@ -474,7 +474,7 @@ bool OutputDevice::TransformAndReduceBitmapExToTargetRange(
         aVisibleRange.transform(aMakeVisibleRangeRelative);
     }
 
-    // for pixel devices, do *not* limit size, else OutputDevice::ImplDrawAlpha
+    // for pixel devices, do *not* limit size, else OutputDevice::DrawAlphaBitmap
     // will create another, badly scaled bitmap to do the job. Nonetheless, do a
     // maximum clipping of something big (1600x1280x2). Add 1.0 to avoid rounding
     // errors in rough estimations
@@ -880,8 +880,6 @@ void OutputDevice::DrawImage( const Point& rPos, const Size& rSize,
 
 Bitmap OutputDevice::GetBitmap( const Point& rSrcPt, const Size& rSize ) const
 {
-    OSL_ENSURE(OUTDEV_PRINTER != GetOutDevType(), "OutputDevice::GetBitmap with sorce type OUTDEV_PRINTER should not be used (!)");
-
     Bitmap  aBmp;
     long    nX = ImplLogicXToDevicePixel( rSrcPt.X() );
     long    nY = ImplLogicYToDevicePixel( rSrcPt.Y() );


More information about the Libreoffice-commits mailing list
diff --git a/include/vcl/outdev.hxx b/include/vcl/outdev.hxx
index 990c47a..defa3dd 100644
--- a/include/vcl/outdev.hxx
+++ b/include/vcl/outdev.hxx
@@ -404,7 +404,7 @@ public:
     SAL_DLLPRIVATE SalGraphics const *ImplGetGraphics() const;
     SAL_DLLPRIVATE SalGraphics*     ImplGetGraphics();
 
     /** Initialize the graphics device that the output device uses to draw on.
 
      There is an LRU of OutputDevices that is used to get the graphics. The
      actual creation of a SalGraphics instance is done via the SalFrame
@@ -412,7 +412,7 @@ public:
 
      However, the SalFrame instance will only return a valid SalGraphics
      instance if it is not in use or there wasn't one in the first place. When
-     this happens, ImplInitGraphics finds the least recently used OutputDevice
+     this happens, AcquireGraphics finds the least recently used OutputDevice
      in a different frame and "steals" it (releases it then starts using it).
 
      If there are no frames to steal an OutputDevice's SalGraphics instance from
@@ -423,7 +423,7 @@ public:
 
      @returns true if was able to initialize the graphics device, false otherwise.
      */
-    virtual bool                ImplInitGraphics() const = 0;
+    virtual bool                AcquireGraphics() const = 0;
 
     /** Release the graphics device, and remove it from the graphics device
      list.
@@ -404,7 +404,7 @@ public:
     SAL_DLLPRIVATE SalGraphics*     ImplGetGraphics();
 
-    /** Initialize the graphics device that the output device uses to draw on.
+    /** Acquire a graphics device that the output device uses to draw on.
 
      There is an LRU of OutputDevices that is used to get the graphics. The